# python-nc2480

![demo](https://github.com/mdcb/python-nc2480/blob/master/nc2480.png "demo")



+ fonts
fonttosfnt -v -b -c -g 2 -m 2 -o vu2480-terminal.otb vu2480-terminal.bdf
cp vu2480-terminal.otb vu2480-terminal.bdf ~/.local/share/fonts/

